==> mastapy-14.0.0b1.tar.gz: mastapy-14.0.0b1/mastapy/_private/_internal/implicit/overridable/iso_tolerance_standard.py <==
"""Implementations of 'Overridable' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""
from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private.gears import _344
from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import

_OVERRIDABLE = python_net_import("SMT.MastaAPI.Utility.Property", "Overridable")

if TYPE_CHECKING:
    from typing import Type, Any, TypeVar

    Self = TypeVar("Self", bound="Overridable_ISOToleranceStandard")


__docformat__ = "restructuredtext en"
__all__ = ("Overridable_ISOToleranceStandard",)


class Overridable_ISOToleranceStandard(mixins.OverridableMixin, Enum):
    """Overridable_ISOToleranceStandard

    A specific implementation of 'Overridable' for 'ISOToleranceStandard' types.
    """

    __qualname__ = "ISOToleranceStandard"

    @classmethod
    def wrapper_type(cls: "Type[Overridable_ISOToleranceStandard]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _OVERRIDABLE

    @classmethod
    def wrapped_type(
        cls: "Type[Overridable_ISOToleranceStandard]",
    ) -> "_344.ISOToleranceStandard":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _344.ISOToleranceStandard
        """
        return _344.ISOToleranceStandard

    @classmethod
    def implicit_type(cls: "Type[Overridable_ISOToleranceStandard]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _344.ISOToleranceStandard.type_()

    @property
    def value(self: "Self") -> "_344.ISOToleranceStandard":
        """mastapy._private.gears.ISOToleranceStandard

        Note:
            This property is readonly.
        """
        return None

    @property
    def overridden(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        return None

    @property
    def override_value(self: "Self") -> "_344.ISOToleranceStandard":
        """mastapy._private.gears.ISOToleranceStandard

        Note:
            This property is readonly.
        """
        return None

    @property
    def calculated_value(self: "Self") -> "_344.ISOToleranceStandard":
        """mastapy._private.gears.ISOToleranceStandard

        Note:
            This property is readonly.
        """
        return None

==> mastapy-14.1.3.tar.gz: mastapy-14.1.3/mastapy/_private/_internal/implicit/overridable/iso_tolerance_standard.py <==
"""Implementations of 'Overridable' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.gears import _352

_OVERRIDABLE = python_net_import("SMT.MastaAPI.Utility.Property", "Overridable")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Overridable_ISOToleranceStandard")


__docformat__ = "restructuredtext en"
__all__ = ("Overridable_ISOToleranceStandard",)


class Overridable_ISOToleranceStandard(mixins.OverridableMixin, Enum):
    """Overridable_ISOToleranceStandard

    A specific implementation of 'Overridable' for 'ISOToleranceStandard' types.
    """

    __qualname__ = "ISOToleranceStandard"

    @classmethod
    def wrapper_type(cls: "Type[Overridable_ISOToleranceStandard]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _OVERRIDABLE

    @classmethod
    def wrapped_type(
        cls: "Type[Overridable_ISOToleranceStandard]",
    ) -> "_352.ISOToleranceStandard":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _352.ISOToleranceStandard
        """
        return _352.ISOToleranceStandard

    @classmethod
    def implicit_type(cls: "Type[Overridable_ISOToleranceStandard]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _352.ISOToleranceStandard.type_()

    @property
    def value(self: "Self") -> "_352.ISOToleranceStandard":
        """mastapy.gears.ISOToleranceStandard

        Note:
            This property is readonly.
        """
        return None

    @property
    def overridden(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        return None

    @property
    def override_value(self: "Self") -> "_352.ISOToleranceStandard":
        """mastapy.gears.ISOToleranceStandard

        Note:
            This property is readonly.
        """
        return None

    @property
    def calculated_value(self: "Self") -> "_352.ISOToleranceStandard":
        """mastapy.gears.ISOToleranceStandard

        Note:
            This property is readonly.
        """
        return None
